Coverage for mcpgateway/__init__.py: 100%

1# -*- coding: utf-8 -*-

2"""MCP Gateway - A flexible feature-rich FastAPI-based gateway for the Model Context Protocol (MCP).

3

4 Copyright 2025

5 SPDX-License-Identifier: Apache-2.0

6 Authors: Mihai Criveti

7

8"""

9

10 __author__ = "Mihai Criveti"

11 __copyright__ = "Copyright 2025"

12 __license__ = "Apache 2.0"

13 __version__ = "0.3.0"

14 __description__ = "IBM Consulting Assistants - Extensions API Library"

15 __url__ = "https://ibm.github.io/mcp-context-forge/"

16 __download_url__ = "https://github.com/IBM/mcp-context-forge"

17 __packages__ = ["mcpgateway"]